@@ -11,8 +11,10 @@
 ##'     matrices for ETAs), this should be `FALSE`, and for
 ##'     variance-covariance matrices (like `THETAP`), this should be
 ##'     `TRUE`.
-##' @param fix Include `FIX` for all lines? If not, none will be
-##'     fixed. Currently, there is no support for keeping
+##' @param fix Include `FIX` for all lines? If `FALSE`, fixing will
+##'     not be modified. Notice, `fix=TRUE` will fix everything -
+##'     individual parameters cannot be controlled. For finer control
+##'     and way more features, see `NMdata::NMwriteInits()`.
 ##' @param type The matrix type. `OMEGA` or `SIGMA` - case
 ##'     in-sensitive. Will be used to print say `$OMEGA` in front of
 ##'     each line.
@@ -20,7 +22,7 @@
 ##'
 ##' @keywords internal
 
-NMcreateMatLines <- function(omegas,as.one.block=FALSE,fix=TRUE,type){
+NMcreateMatLines <- function(omegas,as.one.block=FALSE,fix=FALSE,type){
 
     . <- NULL
     blocksize <- NULL
@@ -34,7 +36,13 @@ NMcreateMatLines <- function(omegas,as.one.block=FALSE,fix=TRUE,type){
     text <- NULL
     value <- NULL
     
-    fun.string.fix <- function(FIX) ifelse(FIX,"FIX","")
+    
+    if(fix){
+        fun.string.fix <- function(FIX) " FIX"
+    } else {
+        fun.string.fix <- function(FIX) ifelse(FIX," FIX","")
+    }
+    
     if(!missing(type)){
         string.type <- paste0("$",toupper(type))
     } else {
@@ -67,14 +75,15 @@ NMcreateMatLines <- function(omegas,as.one.block=FALSE,fix=TRUE,type){
             ## derive fix
             values.this[value==0,value:=1e-30]
             res <- pasteBegin(
-                add=paste0("BLOCK(",this.blocksize,") ",fun.string.fix(values.this[i==i.this&j==i.this,FIX]))
+                add=paste0("BLOCK(",this.blocksize,")",fun.string.fix(values.this[i==i.this&j==i.this,FIX]))
                ,
                 x=values.this[,.(text=paste(value,collapse=" ")),keyby=.(i)]$text
             )
             
         } else {
             res <- values.this[,value]
-            if(values.this[,FIX])  res <- paste(res, fun.string.fix(1))
+            ## if(values.this[,FIX])  res <- paste(res, fun.string.fix(1))
+            res <- paste0(res, fun.string.fix(values.this[,FIX]))
         }
         res <- pasteBegin(add=string.type,x=res)
         loopres <- c(loopres,res)
@@ -83,5 +92,5 @@ NMcreateMatLines <- function(omegas,as.one.block=FALSE,fix=TRUE,type){
     lines.mat <- loopres
 
     return(lines.mat)
-}
 
+}
